# RT-Utils
A minimal python library for ..., built using Pydicom.

# Mask -> RT-Struct
This is the main motivation of the project. Wanted to allow physicians to be able to view 

# RT-Struct -> Mask

# Notes
All contours will use the same Frame of Reference UID.
Using non CT image storage dicom files is undefined behavior.
Will skip adding non CT images 
Only supports 1 structured set of ROI sequence 